package main

import (
	"context"
	"os"
	"os/signal"

	"github.com/sirupsen/logrus"

	"git.janky.solutions/finn/lockserver/config"
	"git.janky.solutions/finn/lockserver/db"
	"git.janky.solutions/finn/lockserver/zwavejs"
)

func main() {
	run()
}

func run() {
	logrus.SetLevel(logrus.DebugLevel)
	ctx, cancel := signal.NotifyContext(context.Background(), os.Interrupt)
	defer cancel()

	if err := db.Migrate(); err != nil {
		logrus.WithError(err).Fatal("error migrating db")
	}

	zwaveClient, err := zwavejs.New(ctx, config.C.ZWaveJSServer)
	if err != nil {
		logrus.WithError(err).Fatal("error initializing ZWaveJS connection")
	}

	<-ctx.Done()

	if err := zwaveClient.Shutdown(); err != nil {
		logrus.WithError(err).Error("error shutting down ZWaveJS client")
	}
}
